import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeRadioButtonGroup from '@s-ui/react-molecule-radio-button-group';
import MoleculeRadioButtonField from '@s-ui/react-molecule-radio-button-field';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var Radio = function Radio(_ref) {
  var radio = _ref.radio,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[radio.id];
  var alertMessages = alerts[radio.id];
  var datalist = radio.datalist;

  var onChangeHandler = function onChangeHandler(value) {
    return onChange(radio.id, value);
  };

  var radioProps = _extends({
    id: radio.id,
    label: radio.label,
    tabIndex: tabIndex
  }, radio.disabled && {
    disabled: true
  }, radio.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (radioProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: radio.id,
    innerProps: _extends({}, radioProps, {
      datalist: datalist
    })
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Radio sui-FormBuilder-" + (radioProps.id || tabIndex),
    children: [radio.label && /*#__PURE__*/_jsx("label", {
      className: "sui-FormBuilder-Radio-label",
      children: radio.label
    }), /*#__PURE__*/_jsx(MoleculeRadioButtonGroup, _extends({
      onChange: function onChange(_, _ref2) {
        var value = _ref2.value;
        onChangeHandler(value);
      },
      id: radio.id,
      value: radio.value
    }, rendererResponse, {
      children: datalist.map(function (button) {
        return /*#__PURE__*/_jsx(MoleculeRadioButtonField, {
          id: button.value,
          value: button.value,
          label: button.text,
          helpText: button.hint
        }, button.value);
      })
    }))]
  });
};

Radio.displayName = 'Radio';
export default /*#__PURE__*/memo(Radio, createComponentMemo('radio'));