import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo, useCallback, useState } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../../prop-types';
import MoleculeAutosuggestField from '@s-ui/react-molecule-autosuggest-field';
import MoleculeAutosuggestOption from '@s-ui/react-molecule-dropdown-option';
import IconClose from '../../Icons/IconClose';
import { removeAccents } from '@s-ui/js/lib/string';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var fromValueToText = function fromValueToText(datalist) {
  return function (value) {
    var item = datalist.find(function (item) {
      return item.value === value;
    });
    return item == null ? void 0 : item.text;
  };
};

var fromTextToValue = function fromTextToValue(datalist) {
  return function (text) {
    var item = datalist.find(function (item) {
      return item.text.toLowerCase() === text.toLowerCase();
    });
    return item == null ? void 0 : item.value;
  };
};

var AutosuggestSelect = function AutosuggestSelect(_ref) {
  var select = _ref.select,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      size = _ref.size,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[select.id];
  var alertMessages = alerts[select.id];
  var _select$datalist = select.datalist,
      datalist = _select$datalist === void 0 ? [] : _select$datalist;
  var fromTextToValueWithDatalist = fromTextToValue(datalist);
  var fromValueToTextWithDatalist = fromValueToText(datalist);
  var textFromValueProp = fromValueToTextWithDatalist(select.value);

  var _useState = useState(''),
      localStateText = _useState[0],
      setLocalStateText = _useState[1]; // case: a value is forced from outside the component
  // if text from prop is different from current local state text, update local text state


  if (textFromValueProp && textFromValueProp !== localStateText) setLocalStateText(textFromValueProp);
  var onChangeCallback = useCallback(function (evt, _ref2) {
    var text = _ref2.value;
    var value = fromTextToValueWithDatalist(text);
    setLocalStateText(text);
    onChange(select.id, value);
  }, [fromTextToValueWithDatalist, onChange, select]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(select.id);
  }; // transform constraints to props


  var constraints = select.constraints || [];
  var constraintsProps = {};
  constraintsProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    if ((constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.notnull) === '') {
      return _extends({}, acc, {
        required: true
      });
    } else {
      return acc;
    }
  }, constraintsProps);

  var autosuggestProps = _extends({
    id: select.id,
    label: select.label,
    name: select.name,
    placeholder: select.hint,
    onChange: onChangeCallback,
    helpText: select.help,
    onBlur: onBlurCallback,
    iconClear: /*#__PURE__*/_jsx(IconClose, {}),
    value: localStateText,
    tabIndex: tabIndex
  }, select.disabled && {
    disabled: true
  }, select.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  }, {
    selectSize: size
  }, constraintsProps);

  if (autosuggestProps.hidden) {
    return null;
  }

  var normalize = function normalize(str) {
    return removeAccents(str.toLowerCase());
  };

  var suggestions = localStateText ? datalist.filter(function (_ref3) {
    var text = _ref3.text,
        value = _ref3.value;
    return normalize(text).match(normalize(localStateText));
  }) : datalist;
  var rendererResponse = renderer({
    id: select.id,
    innerProps: _extends({}, autosuggestProps, {
      datalist: datalist
    })
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-AutosuggestSelect sui-FormBuilder-" + autosuggestProps.id,
    children: [autosuggestProps.label && /*#__PURE__*/_jsx("label", {
      className: "sui-FormBuilder-label",
      htmlFor: autosuggestProps.id,
      children: autosuggestProps.label
    }), /*#__PURE__*/_jsx(MoleculeAutosuggestField, _extends({}, autosuggestProps, rendererResponse, {
      children: suggestions.map(function (suggestion, i) {
        return /*#__PURE__*/_jsx(MoleculeAutosuggestOption, {
          value: suggestion.text,
          children: suggestion.text
        }, suggestion.value);
      })
    }))]
  });
};

AutosuggestSelect.displayName = 'AutosuggestSelect';
export default /*#__PURE__*/memo(AutosuggestSelect, createComponentMemo('select'));